export class CssClassList {
  public list: Array<string> = [];

  /**
   * constructor
   * @param  {Array<string>} ...args
   * @return {CssClassList}
   */
  constructor(... args: Array<string>) {
    this.list = args;
  }

  /**
   * adds a className
   * @param  {string}       className
   * @return {CssClassList}
   */
  public add(className: string): CssClassList {
    this.remove(className);
    this.list.push(className);
    return this;
  }

  /**
   * returns if the instance has a className
   * @param  {string}  className
   * @return {boolean}
   */
  public has(className: string): boolean {
    return this.list.filter(item => item === className).length > 0;
  }

  /**
   * removes a className
   * @param  {string}       className
   * @return {CssClassList}
   */
  public remove(className: string): CssClassList {
    this.list = this.list.filter(item => item !== className);
    return this;
  }

  /**
   * toggles a single css class
   * @param  {string}       className
   * @return {CssClassList}
   */
  public toggle(className: string): CssClassList {
    this.has(className) ? this.remove(className) : this.add(className);
    return this;
  }

  /**
   * outputs css classes to string
   * @return {string}
   */
  public toString(): string {
    return this.list.join(' ').trim();
  }
}
