function clone<TObject>(object: TObject): TObject {
  let _object;
  _object = {};
  Object.keys(object).forEach((key: string) => _object[key] = object[key]);
  return _object;
}

export class Store<TStore> {
  private _data: TStore;
  private _history: Array<TStore> = [];
  private _initial: TStore;

  constructor(data: TStore) {
    this._data = clone<TStore>(data);
    this._history.push(this._data);
    this._initial = clone<TStore>(data);
  }

  private _store(): void {
    this._history.push(this._data);
  }

  private _storeRollback(): void {
    let _canRollback: boolean = this._history.length > 1;
    if (_canRollback) {
      let _lastEntry = this._history[this._history.length - 1];
      this._update(_lastEntry);
    }
  }

  private _update(data: TStore) {
    Object.keys(data).forEach(_key => this._data[_key] = data[_key]);
  }

  public clone(): Store<TStore> {
    return new Store(this.get());
  }

  public get(): TStore {
    return this._data;
  }

  public reset(): void {
    this._data = clone(this._initial);
  }

  public rollback(): void {
    this._storeRollback();
  }

  public update(data: TStore) {
    this._update(data);
    this._store();
  }

  public updateStrict(data: TStore) {
    Object.keys(data).forEach(_key => { if (_key in this._initial) this._data[_key] = data[_key] });
    this._store();
  }
}
