import { capitalizeFirst } from '../../utilities/string';
import { CssClassList } from '../../classes/css';
import * as appCss from 'ride-components/dist/ts/css/app';
import * as React from 'react';

export interface IAppContentProperties {
  /**
   * app content color
   * @type {string}
   */
  color?: string;
  /**
   * app content title
   * @type {string}
   */
  title?: string;
  /**
   * app content toolbar component content
   * @type {string}
   */
  toolbar?: any;
  /**
   * app content toolbar component color
   * @type {string}
   */
  toolbarColor?: string;
}

export class AppContent extends React.Component<IAppContentProperties, any> {
  public render() {
    let _css = new CssClassList(appCss.app__content);
    let _cssToolbar = new CssClassList(appCss.app__toolbar);
    _css.add(
      this.props.color
      ? appCss[appCss.app__content + capitalizeFirst(this.props.color)]
      : appCss.app__contentWhite
    );
    _cssToolbar.add(
      this.props.toolbarColor
      ? appCss.app__toolbar + capitalizeFirst(this.props.color)
      : appCss.app__toolbarBlue
    )
    return (
      <main className={_css.toString()}>
        <div className={_cssToolbar.toString()} hidden={!this.props.title && this.props.toolbar}> {this.props.title} {this.props.toolbar} </div>
        {this.props.children}
      </main>
    )
  }
}
