import { capitalizeFirst } from '../../utilities/string';
import { CssClassList } from '../../classes/css';
import * as css from 'ride-components/dist/ts/css/baloon';
import * as React from 'react';

export interface IBaloonProps {
  /**
   * additional css classes
   */
  className?: string;
  /**
   * baloon header/arrow colour
   */
  color?: string;
  /**
   * baloon direction
   * 		bottom: the baloon will appear from bottom
   * 		top: the baloon will appear from top
   */
  direction?: string;
  /**
   * baloon title
   */
  title?: string;
  /**
   * flags if the baloon is visible or not
   */
  visible?: boolean;
}

export interface IBaloonState {}

export class Baloon extends React.Component<IBaloonProps, IBaloonState> {
  public render() {
    let _css = new CssClassList(css.baloon);
    _css.add(this.props.className || '');
    _css.add(css[css.baloon + capitalizeFirst(this.props.color)]);
    _css.add(css[css.baloon + capitalizeFirst(this.props.direction || 'bottom')]);
    if (this.props.visible) _css.add(css.baloonVisible);
    return (
      <div className={_css.toString()}>
        {
          this.props.direction === 'bottom' || !this.props.direction ? <div className={css.baloon__triangle}></div> : null
        }
        <div className={css.baloon__header} hidden={!this.props.title}>{this.props.title}</div>
        <div className={css.baloon__content}>{this.props.children}</div>
        {
          this.props.direction === 'top' ? <div className={css.baloon__triangle}></div> : null
        }
      </div>
    )
  }
}
