import { capitalizeFirst } from '../../utilities/string';
import { CssClassList } from '../../classes/css';
import * as css from 'ride-components/dist/ts/css/button';
import * as React from 'react';

export interface IButtonProps {
  /**
   * if set to true, the button will span the full width of it's own container element
   * @type {boolean}
   */
  block?: boolean;
  /**
   * you can add every css class you want
   * @type {string}
   */
  className?: string;
  /**
   * This will add the related css colour class
   * 	available colours:
   * 		black
   *     blue
   *     gray
   *     green
   *     orange
   *     purple
   *     red
   *     white
   *     yellow
   * @type {string}
   */
  color?: string;
  /**
   * if set to true, the button will be hollow
   * @type {boolean}
   */
  hollow?: boolean;
  /**
   * if provided, the css button will have a glyphicon element with the provided className
   * @type {string}
   */
  icon?: string;
  /**
   * the onClick callback event
   * @type {any}
   */
  onClick?: any;
  /**
   * the onTouchEnd callback event
   * @type {any}
   */
  onTouchEnd?: any;
  /**
   * the onTouchStart callback event
   * @type {any}
   */
  onTouchStart?: any;
  /**
   * this will add a btn--rounded css class
   */
  rounded?: boolean;
  /**
   * button's title
   * @type {string}
   */
  title?: string;
}

export class Button extends React.Component<IButtonProps, {}> {
  public render() {
    // let css = 'btn';
    let _css = new CssClassList(css.button);
    _css.add(this.props.className || '');
    _css.add(
      this.props.color
      ? css[css.button + capitalizeFirst(this.props.color)]
      : css.buttonBlue
    )
    if (this.props.block) _css.add(css.buttonBlock);
    // if (this.props.hollow) _css.add(btn.hollow);
    if (this.props.icon) _css.add(css.buttonIcon);
    if (this.props.rounded) _css.add(css.buttonRounded);
    return (
      <span
        className={_css.toString()}
        onClick={this.props.onClick}
        onTouchEnd={this.props.onTouchEnd}
        onTouchStart={this.props.onTouchStart}
        title={this.props.title}
      >
        {
          this.props.icon ? <i className={`${css.button__icon} ${this.props.icon}`}/> : null
        }
        {this.props.children}
      </span>
    )
  }
}
