import { capitalizeFirst } from '../../utilities/string';
import { CssClassList } from '../../classes/css';
import { FontIcon } from '../icons/font-icon';
import { ToolbarItem } from '../app/toolbar';
import * as css from 'ride-components/dist/ts/css/dialog';
import * as React from 'react';

export interface IDialogProps {
  /**
   * close icon css
   */
  closeIcon?: any;
  /**
   * dialog's header css
   */
  colour?: string;
  /**
   * if set to true, the dialog will occupy the entire screen
   */
  fullSize?: boolean;
  /**
   * Pass a React.Component to the Dialog Footer
   */
  footer?: any;
  /**
   * Dialog's position
   *  available positions are
   *    bottom
   *    center
   *    top
   * @type {string}
   */
  position: string;
  /**
   * Dialog header's title
   * @type {string}
   */
  title: string;
  /**
   * If set to true, the dialog will be visible
   */
  visible?: boolean;
}

export class Dialog extends React.Component<IDialogProps, {}> {
  public render() {
    let _css = new CssClassList(css.dialog);
    _css.add(
      this.props.colour
      ? css[css.dialog + capitalizeFirst(this.props.colour)]
      : css.dialogBlue
    )
    if (this.props.fullSize) _css.add(css.dialogFullSize);
    if (this.props.position && this.props.position.length) _css.add(css.dialog + capitalizeFirst(this.props.position));
    if (this.props.visible) _css.add(css.dialogVisible);
    return (
      <div>
        <section className={_css.toString()}>
          <header className={css.dialog__header}>
            {this.props.title}
            {
              this.props.closeIcon ? this.props.closeIcon : null
            }
          </header>
          <div className={css.dialog__content}>{this.props.children}</div>
          {
            this.props.footer ? <footer className={css.dialog__footer}>{this.props.footer}</footer> : null
          }
        </section>
      </div>
    )
  }
}
