import { camelize, capitalizeFirst } from '../../utilities/string';
import { CssClassList } from '../../classes/css';
import * as checkbox from 'ride-components/dist/ts/css/input-checkbox';
import * as radio from 'ride-components/dist/ts/css/input-radio';
import * as React from 'react';

export interface ICheckboxProperties {
  /**
   * if set to true, the Component will be checked
   * @optional
   */
  checked?: boolean;
  /**
   * Component colour
   * @optional
   */
  color?: string;
  /**
   * Triggered when the user changes the value (checked/unchecked)
   * @type {Function}
   */
  onChange: any;
  /**
   * HTML name attribute
   * @optional
   */
  name?: string;
  /**
   * HTML type attribute
   *  you can choose between checkbox and radio.
   *  default: checkbox
   * @optional
   */
  type?: string;
}

export class Checkbox extends React.Component<ICheckboxProperties, {}> {
  public onchange(event) {
    this.props.onChange(event);
  }

  public render() {
    let _css = new CssClassList(checkbox.inputCheckbox);
    let _inputType = this.props.type === 'checkbox' || this.props.type === 'radio' ? this.props.type : 'checkbox';
    _css.add(
      this.props.color
      ? checkbox[camelize(checkbox.inputCheckbox) + capitalizeFirst(this.props.color)]
      : checkbox.inputCheckboxBlue
    );
    return (
      <label className={_css.toString()}>
        <input checked={this.props.checked} name={this.props.name} onChange={this.onchange.bind(this)} type={_inputType}/>
        <span>{this.props.children}</span>
      </label>
    )
  }
}

export class Radio extends Checkbox {
  public render() {
    let _css = new CssClassList(radio.inputRadio);
    _css.add(
      this.props.color
      ? radio[camelize(radio.inputRadio) + capitalizeFirst(this.props.color)]
      : radio.inputRadioBlue
    );
    return (
      <label className={_css.toString()}>
        <input checked={this.props.checked} name={this.props.name} onChange={this.onchange.bind(this)} type="radio"/>
        <span>{this.props.children}</span>
      </label>
    )
  }
}
