import { camelize, capitalizeFirst } from '../../utilities/string';
import { CssClassList } from '../../classes/css';
import * as range from 'ride-components/dist/ts/css/input-range';
import * as React from 'react';

export interface IFormRangeProps {
  /**
   * range bar here
   */
  color?: string;
  /**
   * the maximum value allowed
   *  default: 100
   */
  max?: number;
  /**
   * the minimum value allowed
   *  default: 0
   */
  min?: number;
  /**
   * Invokes a callback when the user changes the value of the range input.
   * @type {Function}
   */
  onChange?: any;
  /**
   * the step html attribute
   *  default: 1
   */
  step?: number;
  /**
   * The default value
   */
  value?: number;
}

export interface IFormRangeState {

}

export class Range extends React.Component<IFormRangeProps, IFormRangeState> {
  public render() {
    let css = new CssClassList(range.inputRange);
    let value = this.props.value ? this.props.value.toString() : null;

    css.add(this.props.color ? range[camelize(range.inputRange) + capitalizeFirst(this.props.color)] : range.inputRangeBlue);

    return (
      <input
        className={css.toString()}
        onChange={this.props.onChange}
        max={this.props.max || 100}
        min={this.props.min || 0}
        step={this.props.step || 1}
        type="range"
        value={value}/>
    )
  }
}
