import { CssClassList } from '../../classes/css';
import * as list from 'ride-components/dist/ts/css/list';
import * as React from 'react';

export interface IListItemProperties {
  /**
   * if set to true, the list item will be marked as current
   * @type {boolean}
   */
  current?: boolean;
  /**
   * additional className
   * @type {string}
   */
  className?: string;
  /**
   * if set to true, the element will be hidden
   *  default: false
   * @type {boolean}
   */
  hidden?: boolean;
  /**
   * if se to true, the item will be unpadded
   */
  unpadded?: boolean;
}

export class ListItem extends React.Component<IListItemProperties, any> {
  public render() {
    let _css = new CssClassList(list.list__item);
    if (this.props.current) _css.add(list.list__itemCurrent);
    if (this.props.unpadded) _css.add(list.list__itemUnpadded);
    let hidden = this.props.hidden;
    return (
      <li className={_css.toString()} hidden={hidden}>{this.props.children}</li>
    )
  }
}

export interface IListProperties {
  /**
   * additional css className
   * @type {string}
   */
  className?: string;
  /**
   * if set to true, the Component will be hidden
   *  default: false
   */
  hidden?: boolean;
  /**
   * if set to true, the list will be indented
   *  default: false
   */
  indented?: boolean;
  /**
   * if set to true, the list will not have padding
   *  default: false
   */
  unpadded?: boolean;
  /**
   * if set to true, the list will be vertical
   *  default: false
   */
  vertical?: boolean;
}

export class List extends React.Component<IListProperties, {}> {
  public static Item = ListItem;

  public render() {
    let _css = new CssClassList(list.list);
    if (this.props.indented) _css.add(list.listIndented);
    if (this.props.unpadded) _css.add(list.listUnpadded);
    if (this.props.vertical) _css.add(list.listVertical);
    if (this.props.className) _css.add(this.props.className);

    return (
      <ul className={_css.toString()} hidden={this.props.hidden}>{this.props.children}</ul>
    )
  }
}
