import { camelize, capitalizeFirst } from '../../utilities/string';
import { CssClassList } from '../../classes/css';
import * as notification from 'ride-components/dist/ts/css/notification';
import * as React from 'react';

export interface INotificationProperties extends INotificationState {
  /**
   * sets the colour for the Notification component
   * @type {string}
   */
  color?: string;
  /**
   * if set to true, the notification will be hollow.
   *  default: false
   * @type {boolean}
   */
  hollow?: boolean;
  /**
   * if set to true, the notification will be rounded
   *  default: false
   * @type {boolean}
   */
  rounded?: boolean;
}

export interface INotificationState {
  /**
   * if set to true, the notification will be visible
   */
  visible?: boolean;
}

export class Notification extends React.Component<INotificationProperties, {}> {
  public render() {
    let _css = new CssClassList(notification.notification);
    _css.add(this.props.color ? notification[camelize(notification.notification) + capitalizeFirst(this.props.color)] : notification.notificationBlue);
    if (this.props.hollow) _css.add(notification.notificationHollow);
    if (this.props.rounded) _css.add(notification.notificationRounded);
    return (
      <div className={_css.toString()} hidden={!this.props.visible}>{this.props.children}</div>
    )
  }
}
