import { camelize, capitalizeFirst } from '../../utilities/string';
import { CssClassList } from '../../classes/css';
import * as popup from 'ride-components/dist/ts/css/popup';
import * as React from 'react';

export interface IPopupProps {
  /**
   * the popup colour
   *  default: blue
   * @type {string}
   */
  color?: string;
  /**
   * if set to true, the popup will be rounded
   *  @type {boolean}
   */
  rounded?: boolean;
  /**
   * sets the text for the popup
   */
  text?: string;
  /**
  * if set to true, the popup will be visible
  *  @type {boolean}
  */
  visible?: boolean;
}

export class Popup extends React.Component<IPopupProps, {}> {
  public render() {
    let _css = new CssClassList(popup.popup);
    _css.add(this.props.color ? popup[camelize(popup.popup) + capitalizeFirst(this.props.color)] : popup.popupBlue);
    if (this.props.visible) _css.add(popup.popupVisible);
    if (this.props.rounded) _css.add(popup.popupRounded);
    return (
      <div>
        <div className={_css.toString()}>
          <div className={popup.popup__text}>{this.props.text}</div> {this.props.children}
        </div>
      </div>
    )
  }
}
