import { Pagination } from '../../classes/Pagination';
import { Button } from '../buttons/button';
import * as React from 'react';

export interface IPaginationButtonsProps {
  color: string;
  colorActive: string;
  config: Pagination<any>;
  hideFirst?: boolean;
  hideLast?: boolean;
  hideNext?: boolean;
  hidePrev?: boolean;
  textFirst?: string;
  textLast?: string;
  textNext?: string;
  textPrev?: string;
}

export class PaginationButtons extends React.Component<IPaginationButtonsProps, {}> {
  private getCurrentColour(pageNumber: number): string {
    return this.props.config.isCurrent(pageNumber) ? this.getDefaultButtonColorActive() : this.getDefaultButtonColor();
  }

  private getDefaultButtonColor(): string {
    return !!this.props.color ? this.props.color : 'gray';
  }
  private getDefaultButtonColorActive(): string {
    return !!this.props.colorActive ? this.props.colorActive : 'blue';
  }

  public render() {
    return (
      <div>
        {
          this.props.hideFirst ? null : <Button onClick={this.props.config.getPageFirst()}>{this.props.textFirst ? this.props.textFirst : 'First page'}</Button>
        }
        {
          this.props.hidePrev ? null : <Button onClick={this.props.config.getPagePrev()}>{this.props.textPrev ? this.props.textPrev : null}</Button>
        }
        {
          this.props.config.pageCount.map(pagenumber =>
            <Button
              color={this.getCurrentColour(pagenumber)}
              onClick={this.props.config.getPage(pagenumber)}>{pagenumber}
            </Button>
          )
        }
        {
          this.props.hideNext ? null : <Button onClick={this.props.config.getPageNext()}>{this.props.textNext ? this.props.textNext : null}</Button>
        }
        {
          this.props.hideLast ? null : <Button onClick={this.props.config.getPageLast()}>{this.props.textLast ? this.props.textLast : 'Last page'}</Button>
        }
      </div>
    )
  }
}
