import { Button } from '../buttons/button';
import { List } from '../lists/list';
import * as React from 'react';

export interface ITabsProps {
  /**
   * buttons colours
   * @type {string}
   */
  buttonColor?: string;
  /**
   * active button colour
   * @type {string}
   */
  buttonActiveColor?: string;
  /**
   * buttons list
   * @type {string[]}
   */
  buttons: Array<string>;
  /**
   * if set to true, the component will be hidden
   * @type {string}
   */
  hidden?: boolean;
  /**
   * if set to true, the matching button will be selected
   * @type {string}
   */
  selected?: string;
  /**
   * if set to true, the buttons will be displayed vertically
   * @type {string}
   */
  vertical?: boolean;
}

export interface ITabsState {
  /**
   * tells the component which tab is active (this string should match a button)
   * @type {string}
   */
  current: string;
}

export class Tabs extends React.Component<ITabsProps, ITabsState> {
  constructor(props: ITabsProps) {
    super(props);
    if (!this.props.buttons) throw new Error('Tabs: missing button property. It must be an Array<string>.');
    this.state = { current: this.props.selected || this.props.buttons[0] };
  }

  public getCurrentCss(name: string) {
    return this.isCurrent(name) ? this.props.buttonActiveColor : this.props.buttonColor;
  }

  public isCurrent(name: string) {
    return this.state.current === name;
  }

  public setAsCurrent(name: string) {
    this.state.current = name;
    this.setState(this.state);
  }

  public render() {
    return (
      <div hidden={this.props.hidden}>
        <List indented={false} vertical={this.props.vertical}>
          {
            this.props.buttons.map((button, index) =>
              <List.Item key={index}>
                <Button onClick={this.setAsCurrent.bind(this, button)} color={this.getCurrentCss.bind(this)(button)}>{button}</Button>
              </List.Item>
            )
          }
        </List>
        <List indented={false} vertical={true} unpadded={true}>
          {
            this.props.buttons.map((tab, index) =>
              this.isCurrent.bind(this)(this.props.buttons[index]) ?
                <List.Item key={index}>{this.props.children ?
                  Array.isArray(this.props.children) ? this.props.children[index] : this.props.children : null
                }</List.Item>
              : null
            )
          }
        </List>
      </div>
    )
  }
}
