'use strict';

const fs = require('fs');
const path = require('path');
const webpack = require('webpack');
const webpackFailPlugin = require('webpack-fail-plugin');

const DIST_DIR = path.join(process.cwd(), './dist');
const DTS_DIR = path.join(process.cwd(), './d.ts');

var deleteFolderRecursive = function (_path) {
  if(fs.existsSync(_path) ) {
    fs.readdirSync(_path).forEach(function (file) {
      var curPath = path.join(_path, './'+ file);
      if(fs.lstatSync(curPath).isDirectory()) {
        deleteFolderRecursive(curPath);
      } else {
        fs.unlinkSync(curPath);
      }
    });
    fs.rmdirSync(_path);
  }
};

var alias = {
  'ride-components': path.join(process.cwd(), './node_modules')
}
var entryfile = './src/components/bundle.tsx';
var extensions = [
  ''
, '.js'
, '.ts'
, '.tsx'
, '.web.js'
, '.webpack.js'
];
var externals = {
  'react': 'React'
, 'react-dom': 'ReactDOM'
};
var library = [
  'ride'
, 'components'
];
var resolve = {
  extensions: extensions,
  modules: {
    'react': path.join(process.cwd(), './node_modules/')
  , 'react-dom': path.join(process.cwd(), './node_modules/')
  , 'ride-components': path.join(process.cwd(), './node_modules')
  }
}
var stats = {
  colors: true
, errorDetails: true
, modules: true
, reasons: true
}
var tsLoader = {
  loader: 'ts-loader?configFileName=webpack.tsconfig.json',
  test: /\.tsx?$/
};

var existsDistDir;
var existsDTSDir;

try {
  existsDistDir = fs.statSync(DIST_DIR).isDirectory();
} catch (e) {
  existsDistDir = false;
}

try {
  existsDTSDir = fs.statSync(DTS_DIR).isDirectory();
} catch (e) {
  existsDTSDir = false;
}

if (existsDTSDir) deleteFolderRecursive(DTS_DIR);
if (existsDistDir) deleteFolderRecursive(DIST_DIR);

module.exports = [{
  alias: alias,
  context: process.cwd(),
  devtool: 'source-map',
  entry: {
    bundle: entryfile
  },
  externals: externals,
  module: {
    loaders: [
      tsLoader
    ]
  },
  output: {
    library: library,
    filename: `dist/ride.components.js`
  },
  plugins: [
    webpackFailPlugin
  ],
  resolve: resolve,
  stats: stats
}, {
  alias: alias,
  context: process.cwd(),
  entry: {
    bundle: entryfile
  },
  externals: externals,
  module: {
    loaders: [
      tsLoader
    ]
  },
  output: {
    library: library,
    filename: `dist/ride.components.min.js`
  },
  plugins: [
    webpackFailPlugin
  , new webpack.optimize.UglifyJsPlugin()
  ],
  resolve: resolve,
  stats: stats
}];
